@@ -32,6 +32,36 @@ __all__ = ['LineClient']
 
 EMAIL_REGEX = re.compile(r"[^@]+@[^@]+\.[^@]+")
 
+class LineGroup(object):
+    """Group object for LINE"""
+    def __init__(self, client, group):
+        self._client  = client
+        self._group = group
+
+        self.id      = group.id
+        self.name    = group.name
+        self.creator = LineContact(client, group.creator)
+
+        self.members = []
+        for member in group.members:
+            self.members.append(LineContact(client, member))
+
+    def sendMessage(self, text):
+        try:
+            self._client._sendMessage(id=self.id, text=text)
+            return True
+        except Exception as e:
+            raise e
+
+    def getRecentMessages(self, count=1):
+        return self._client._getRecentMessages(self._group, count)
+
+    def __repr__(self):
+        return '<LineGroup %s (%s명)>' % (self.name, len(self.members))
+
+    def __lt__(self, other):
+        return self.id < other.id
+
 class LineContact(object):
     """Contact object for LINE"""
     def __init__(self, client, contact):
@@ -44,7 +74,7 @@ class LineContact(object):
 
     def sendMessage(self, text):
         try:
-            self._client.sendMessage(id=self.mid, text=text)
+            self._client._sendMessage(id=self.mid, text=text)
             return True
         except Exception as e:
             raise e
@@ -60,7 +90,7 @@ class LineClient(object):
 
         >>> client = LineClient(\'carpedm20\', \'xxxxxxxxxx\')
         Enter PinCode '9779' to your mobile phone in 2 minutes
-        >>> print client.getProfile()
+        >>> print client.profile
     """
 
     LINE_DOMAIN = "http://gd2.line.naver.jp"
@@ -75,6 +105,7 @@ class LineClient(object):
     version     = "3.7.0"
     com_name    = ""
 
+    profile  = None
     contacts = []
     rooms    = []
     groups   = []
@@ -114,7 +145,7 @@ class LineClient(object):
         if authToken:
             self.authToken = self._headers['X-Line-Access'] = authToken
 
-            self._ready()
+            self.ready()
         else:
             if EMAIL_REGEX.match(id):
                 self.provider = CurveThrift.Provider.LINE # LINE
@@ -125,10 +156,11 @@ class LineClient(object):
             self.password = password
             self.is_mac = is_mac
 
-            self._login()
-            self._ready()
+            self.login()
+            self.ready()
 
         self.refreshContacts()
+        self.refreshGroups()
 
     def raise_error(self, msg):
         raise Exception("Error: %s" % msg)
@@ -145,7 +177,7 @@ class LineClient(object):
             msg = "you need to login"
             self.raise_error(msg)
 
-    def getProfile(self):
+    def _getProfile(self):
         """Get profile information
         
         :returns: Profile object
@@ -165,25 +197,39 @@ class LineClient(object):
         if self.check_auth():
             return self.client.getProfile()
 
+    def refreshGroups(self):
+        """Refresh groups of LineClient """
+        group_ids = self._getGroupIdsJoined()
+        groups    = self._getGroups(group_ids)
+
+        self.groups = []
+
+        for group in groups:
+            self.groups.append(LineGroup(self, group))
+
+        self.groups.sort()
+
     def refreshContacts(self):
-        contact_ids = self.getAllContactIds()
-        contacts    = self.getContacts(contact_ids)
+        """Refresh contacts of LineClient """
+        contact_ids = self._getAllContactIds()
+        contacts    = self._getContacts(contact_ids)
 
         self.contacts = []
 
         for contact in contacts:
             self.contacts.append(LineContact(self, contact))
 
-        self.profile  = self.getProfile()
-        self.contacts.append(LineContact(self, self.profile))
+        self.profile = LineContact(self, self._getProfile())
+
+        self.contacts.append(self.profile)
         self.contacts.sort()
 
-    def getAllContactIds(self):
+    def _getAllContactIds(self):
         """Get all contacts of your LINE account"""
         if self.check_auth():
             return self.client.getAllContactIds()
 
-    def getContacts(self, ids):
+    def _getContacts(self, ids):
         """Get contact information list from ids
         
         :returns: List of Contact list
@@ -213,12 +259,12 @@ class LineClient(object):
         if self.check_auth():
             return self.client.getContacts(ids)
 
-    def getGroupIdsJoined(self):
+    def _getGroupIdsJoined(self):
         """Get group id that you joined"""
         if self.check_auth():
             return self.client.getGroupIdsJoined()
 
-    def getGroups(self, ids):
+    def _getGroups(self, ids):
         if type(ids) != list:
             msg = "argument should be list of group ids"
             raise_error(msg)
@@ -226,21 +272,21 @@ class LineClient(object):
         if self.check_auth():
             return self.client.getGroups(ids)
 
-    def getRecentMessages(self, id, count=1):
+    def _getRecentMessages(self, id, count=1):
         if self.check_auth():
             return self.client.getRecentMessages(id, count)
 
-    def sendMessage(self, id, text, seq=0):
+    def _sendMessage(self, id, text, seq=0):
         if self.check_auth():
             message = CurveThrift.Message(to=id,text=text)
 
             return self.client.sendMessage(seq, message)
 
-    def getLastOpRevision(self):
+    def _getLastOpRevision(self):
         if self.check_auth():
             return self.client.getLastOpRevision()
 
-    def _ready(self):
+    def ready(self):
         self.transport    = THttpClient.THttpClient(self.LINE_HTTP_URL)
         self.transport_in = THttpClient.THttpClient(self.LINE_HTTP_IN_URL)
 
@@ -256,7 +302,7 @@ class LineClient(object):
         self.transport.open()
         self.transport_in.open()
 
-    def _login(self):
+    def login(self):
         """Login to LINE server."""
         if self.provider == CurveThrift.Provider.LINE: # LINE
             j = self.get_json(self.LINE_SESSION_LINE_URL)
